@@ -1,9 +1,11 @@
 from django.utils.translation import gettext_lazy as _
 
 
-class Messages(object):
+class Messages:
     INVALID_CREDENTIALS_ERROR = _("Unable to log in with provided credentials.")
-    INACTIVE_ACCOUNT_ERROR = _("User account is disabled.")
+    INACTIVE_ACCOUNT_ERROR = _(
+        "User account is disabled."
+    )  # not in use since Django 1.10
     INVALID_TOKEN_ERROR = _("Invalid token for given user.")
     INVALID_UID_ERROR = _("Invalid user id or user doesn't exist.")
     STALE_TOKEN_ERROR = _("Stale token for given user.")
