@@ -11,6 +11,6 @@ class CurrentUserOrAdmin(permissions.IsAuthenticated):
 class CurrentUserOrAdminOrReadOnly(permissions.IsAuthenticated):
     def has_object_permission(self, request, view, obj):
         user = request.user
-        if type(obj) == type(user) and obj == user:
+        if type(obj) is type(user) and obj == user:
             return True
         return request.method in SAFE_METHODS or user.is_staff
