@@ -5,3 +5,6 @@ user_registered = Signal()
 
 # User has activated his or her account. Args: user, request.
 user_activated = Signal()
+
+# User has been updated. Args: user, request.
+user_updated = Signal()
