@@ -1,9 +1,9 @@
-from django.conf.urls import url
+from django.urls import re_path
 
 from djoser.social import views
 
 urlpatterns = [
-    url(
+    re_path(
         r"^o/(?P<provider>\S+)/$",
         views.ProviderAuthView.as_view(),
         name="provider-auth",
