@@ -1,7 +1,4 @@
-try:  # pragma: no cover
-    from django.urls import re_path
-except ImportError:
-    from django.conf.urls import url as re_path
+from django.urls import re_path
 
 from djoser import views
 
